import { Component, OnInit, ContentChildren, QueryList, AfterContentInit } from '@angular/core';
import { TabComponent } from '../tab/tab.component';
import { faNewspaper, faFilter } from '@fortawesome/free-solid-svg-icons';
import { from } from 'rxjs';

@Component({
  selector: 'app-tabs',
  templateUrl: './tabs.component.html',
  styleUrls: ['./tabs.component.scss']
})
export class TabsComponent implements OnInit, AfterContentInit {
  faNewspaper = faNewspaper;
  @ContentChildren(TabComponent) tabs: QueryList<TabComponent>;

  public selectTab(tab: TabComponent): void {
    // set direciton for aninmation
    tab.direction = this.getTabAnimationDirection(tab);
    // deactivate all tabs
    this.tabs.toArray().forEach(tab => {
      tab.active = false
    });

    // activate the tab the user has clicked on.
    tab.active = true;

  }

  protected getTabAnimationDirection(tab: TabComponent): 'right' | 'left' | 'none' {
    const activeTab = this.tabs.toArray().filter(tab => tab.active)[0];
    if (activeTab === undefined) {
      return 'none';
    }
    const activeTabIndex = activeTab.tabIndex;
    if (activeTabIndex < tab.tabIndex) {
      return 'right';
    }
    if (activeTabIndex > tab.tabIndex) {
      return 'left';
    }
    return 'none';
  }

  getActiveTab(): TabComponent {
    return this.tabs.toArray().filter(tab => tab.active)[0];
  }

  ngAfterContentInit(): void {
    // get all active tabs
    this.tabs.toArray().forEach((tab: TabComponent, index) => tab.tabIndex = index);
    const activeTabs = this.tabs.filter((tab) => tab.active);
    // if there is no active tab set, activate the first
    if (activeTabs.length === 0) {
      this.selectTab(this.tabs.first);
    }
  }


  constructor() { }

  ngOnInit(): void {

  }

}
